csm_create_transform: Create a cropping systems model (CSM) transformed variable

View source: R/csm_create_transform.R

csm_create_transformR Documentation

Create a cropping systems model (CSM) transformed variable

Description

Create a cropping systems model (CSM) transformed variable

Usage

csm_create_transform(name, definition, units, equation)

Arguments

name

a length-one character vector name of a variable

definition

a length-one character vector that defines the CSM variable

units

a length-one character vector of the units of the CSM variable

equation

an R expression with the equation for the value of the transformed CSM state variable

Value

a list of csm_transform objects

Examples


# Define intermediate factor

sp_factors <- csmbuilder::csm_create_transform(
  name = "fv",
  definition = "vernalization factor",
  units = "relative progress towards complete vernalization (0-1)",
  equation = ~min(c(cum_vrn/vreq, 1)))


csmbuilder documentation built on Sept. 19, 2026, 1:06 a.m.