csm_time_vector: Generate vector of times for simulation

View source: R/csm_time_vector.R

csm_time_vectorR Documentation

Generate vector of times for simulation

Description

Generate vector of times for simulation

Usage

csm_time_vector(t_init, t_max, dt = 1)

Arguments

t_init

a numerical value providing the initial time to use for simulation

t_max

a numerical value providing the final time to use for simulation

dt

a numerical value providing the size of the time step to use for simulation

Value

a numeric vector

Examples


csm_time_vector(0, 100, dt = 0.01)



csmbuilder documentation built on Sept. 19, 2026, 1:06 a.m.