View source: R/csm_time_vector.R
| csm_time_vector | R Documentation |
Generate vector of times for simulation
csm_time_vector(t_init, t_max, dt = 1)
t_init |
a numerical value providing the initial time to use for simulation |
t_max |
a numerical value providing the final time to use for simulation |
dt |
a numerical value providing the size of the time step to use for simulation |
a numeric vector
csm_time_vector(0, 100, dt = 0.01)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.